ControlBlock

Struct ControlBlock 

pub struct ControlBlock {
    pub leaf_version: LeafVersion,
    pub output_key_parity: Parity,
    pub internal_key: XOnlyPublicKey,
    pub merkle_path: Vec<TapNodeHash>,
}
Control block for script path spending

Fields

leaf_version: LeafVersion

Leaf version and output key parity (combined in first byte)

output_key_parity: Parity

Output key parity

internal_key: XOnlyPublicKey

Internal key (32 bytes)

merkle_path: Vec<TapNodeHash>

Merkle path (32-byte hashes)

Implementations

Source

impl ControlBlock

pub fn new( leaf_version: LeafVersion, output_key_parity: Parity, internal_key: XOnlyPublicKey, merkle_path: Vec<TapNodeHash>, ) -> Self

Create a new control block

pub fn for_leaf( tree: &TapTree, leaf: &TapLeaf, internal_key: XOnlyPublicKey, output_key_parity: Parity, ) -> Result<Self, TaprootError>

Create control block for a leaf in a tree

pub fn serialize(&self) -> Vec<u8>

Serialize to bytes

pub fn from_slice(data: &[u8]) -> Result<Self, TaprootError>

Parse from bytes

pub fn verify( &self, output_key: &XOnlyPublicKey, script: &[u8], ) -> Result<bool, TaprootError>

Verify the control block against an output key and script

pub fn size(&self) -> usize

Get the size in bytes

pub fn depth(&self) -> usize

Get the merkle path depth