pub struct ControlBlock {
pub leaf_version: LeafVersion,
pub output_key_parity: Parity,
pub internal_key: XOnlyPublicKey,
pub merkle_path: Vec<TapNodeHash>,
}Expand description
Control block for script path spending
Fields
leaf_version: LeafVersionLeaf version and output key parity (combined in first byte)
output_key_parity: ParityOutput key parity
internal_key: XOnlyPublicKeyInternal key (32 bytes)
merkle_path: Vec<TapNodeHash>Merkle path (32-byte hashes)
Implementations
Sourceimpl ControlBlock
impl ControlBlock
Sourcepub fn new(
leaf_version: LeafVersion,
output_key_parity: Parity,
internal_key: XOnlyPublicKey,
merkle_path: Vec<TapNodeHash>,
) -> Self
pub fn new( leaf_version: LeafVersion, output_key_parity: Parity, internal_key: XOnlyPublicKey, merkle_path: Vec<TapNodeHash>, ) -> Self
Create a new control block
Sourcepub fn for_leaf(
tree: &TapTree,
leaf: &TapLeaf,
internal_key: XOnlyPublicKey,
output_key_parity: Parity,
) -> Result<Self, TaprootError>
pub fn for_leaf( tree: &TapTree, leaf: &TapLeaf, internal_key: XOnlyPublicKey, output_key_parity: Parity, ) -> Result<Self, TaprootError>
Create control block for a leaf in a tree
Sourcepub fn from_slice(data: &[u8]) -> Result<Self, TaprootError>
pub fn from_slice(data: &[u8]) -> Result<Self, TaprootError>
Parse from bytes
Sourcepub fn verify(
&self,
output_key: &XOnlyPublicKey,
script: &[u8],
) -> Result<bool, TaprootError>
pub fn verify( &self, output_key: &XOnlyPublicKey, script: &[u8], ) -> Result<bool, TaprootError>
Verify the control block against an output key and script